[cig-commits] [commit] devel, master: Manual updated for noise simulations (edf524e)

cig_noreply at geodynamics.org cig_noreply at geodynamics.org
Wed Jun 18 16:47:45 PDT 2014


Repository : https://github.com/geodynamics/specfem3d

On branches: devel,master
Link       : https://github.com/geodynamics/specfem3d/compare/6026e367984905ab133865f62fa6293b343759b9...47f703851338234f96397e7da9fbff63d8178b8a

>---------------------------------------------------------------

commit edf524edfb1a0102789df20b8d7ca161646596bc
Author: Yang Luo <yangl at princeton.edu>
Date:   Fri Nov 19 21:51:36 2010 +0000

    Manual updated for noise simulations


>---------------------------------------------------------------

edf524edfb1a0102789df20b8d7ca161646596bc
 noise_tomography/NOISE_TOMOGRAPHY.m                |   4 ++--
 noise_tomography/README_NOISE_TOMOGRAPHY           |  11 ++++++-----
 .../REF_KERNELS/1st_contribution_crosssection.jpg  | Bin 78481 -> 95019 bytes
 .../REF_KERNELS/1st_contribution_mapview.jpg       | Bin 129153 -> 121980 bytes
 .../REF_KERNELS/2nd_contribution_crosssection.jpg  | Bin 111290 -> 147990 bytes
 .../REF_KERNELS/2nd_contribution_mapview.jpg       | Bin 205729 -> 189689 bytes
 noise_tomography/pre-processing                    |  10 ++++++++++
 7 files changed, 18 insertions(+), 7 deletions(-)

diff --git a/noise_tomography/README_NOISE_TOMOGRAPHY b/noise_tomography/README_NOISE_TOMOGRAPHY
index 3d511a8..9ff6eb4 100644
--- a/noise_tomography/README_NOISE_TOMOGRAPHY
+++ b/noise_tomography/README_NOISE_TOMOGRAPHY
@@ -10,6 +10,7 @@ Noise Cross-Correlation Sensitivity Kernels (Tromp et al., 2010, GJI)
 **************
 
    This example shows how one can construct noise cross-correlation sensitivity kernels.
+   Note that this example uses a relatively low resolution, and is only presented for illustrational purpose.
 
 **************
 1. Structure
@@ -30,7 +31,7 @@ Noise Cross-Correlation Sensitivity Kernels (Tromp et al., 2010, GJI)
    ./pre-processing
    
    If you don't, you have to follow commands listed in ./pre-processing, make modifications if needed.
-   Those commands in ./pre-processing should be self-explanatory, and will be fully explained in section 4 of this file.
+   Those commands in ./pre-processing should be self-explanatory.
    You may want to compare them with descriptions in the Manual --- ../../doc/USER_MANUAL/manual_SPECFEM3D.pdf
 
 **************
@@ -68,9 +69,9 @@ Noise Cross-Correlation Sensitivity Kernels (Tromp et al., 2010, GJI)
          "./bin/adj_traveltime_filter.f90" is used to calculate adjoint sources (only works for default set-up)
 
 **************
-4. Explanation
+4. Results
 **************
 
-   Please read explanations in "./pre-processing"
-
-
+   At the end of those simulations, kernel files will be saved in SPECFEM3D/in_out_files/NOISE_TOMOGRAPHY/1st/ & SPECFEM3D/in_out_files/NOISE_TOMOGRAPHY/1st/
+   If mesh2vtu.pl works, you will have 1st_beta_kernel.vtu & 2nd_beta_kernel.vtu in SPECFEM3D/in_out_files/NOISE_TOMOGRAPHY/, which can be directly viewed in Paraview 
+   Once you visualize them in Paraview, you should see pictures similar to those in SPECFEM3D/examples/noise_tomography/REF_KERNELS/
diff --git a/noise_tomography/REF_KERNELS/1st_contribution_crosssection.jpg b/noise_tomography/REF_KERNELS/1st_contribution_crosssection.jpg
index 2f3d359..2f14f8a 100644
Binary files a/noise_tomography/REF_KERNELS/1st_contribution_crosssection.jpg and b/noise_tomography/REF_KERNELS/1st_contribution_crosssection.jpg differ
diff --git a/noise_tomography/REF_KERNELS/1st_contribution_mapview.jpg b/noise_tomography/REF_KERNELS/1st_contribution_mapview.jpg
index 8f4f614..49a72f7 100644
Binary files a/noise_tomography/REF_KERNELS/1st_contribution_mapview.jpg and b/noise_tomography/REF_KERNELS/1st_contribution_mapview.jpg differ
diff --git a/noise_tomography/REF_KERNELS/2nd_contribution_crosssection.jpg b/noise_tomography/REF_KERNELS/2nd_contribution_crosssection.jpg
index 2f19e03..273f07e 100644
Binary files a/noise_tomography/REF_KERNELS/2nd_contribution_crosssection.jpg and b/noise_tomography/REF_KERNELS/2nd_contribution_crosssection.jpg differ
diff --git a/noise_tomography/REF_KERNELS/2nd_contribution_mapview.jpg b/noise_tomography/REF_KERNELS/2nd_contribution_mapview.jpg
index 1739a72..b1a593c 100644
Binary files a/noise_tomography/REF_KERNELS/2nd_contribution_mapview.jpg and b/noise_tomography/REF_KERNELS/2nd_contribution_mapview.jpg differ
diff --git a/noise_tomography/pre-processing b/noise_tomography/pre-processing
index 82692b3..95a5bd3 100755
--- a/noise_tomography/pre-processing
+++ b/noise_tomography/pre-processing
@@ -30,6 +30,10 @@ kernel="beta_kernel"
 mkdir -p $in_out_files/SEM 
 mkdir -p $in_out_files/NOISE_TOMOGRAPHY
 
+# create directories for storing kernels (first contribution and second contribution)
+mkdir -p $in_out_files/NOISE_TOMOGRAPHY/1st
+mkdir -p $in_out_files/NOISE_TOMOGRAPHY/2nd
+
 # copy noise input files
 cp $script_dir/NOISE_TOMOGRAPHY/S_squared                $in_out_files/NOISE_TOMOGRAPHY/
 cp $script_dir/NOISE_TOMOGRAPHY/irec_master_noise*       $in_out_files/NOISE_TOMOGRAPHY/
@@ -90,6 +94,9 @@ cp $in_out_files/SEM/adj_sources_contribution1           $in_out_files/SEM/X2.DB
 cp $in_data_files/Par_file_step3                         $in_data_files/Par_file
 mpirun -np 4 ./xspecfem3D
 
+# store kernels
+cp $in_out_files/DATABASES_MPI/*kernel*                  $in_out_files/NOISE_TOMOGRAPHY/1st/
+
 # visualization (refer to other examples, if you don't know the visualization process very well)
 # note that "xcombine_vol_data" is compiled by "make combine_vol_data"
 # this program generates a file "$in_out_files/OUTPUT_FILES/$kernel.mesh"
@@ -127,6 +134,9 @@ cp $in_out_files/SEM/adj_sources_contribution2           $in_out_files/SEM/X1.DB
 cp $in_data_files/Par_file_step3                         $in_data_files/Par_file
 mpirun -np 4 ./xspecfem3D
 
+# store kernels
+cp $in_out_files/DATABASES_MPI/*kernel*                  $in_out_files/NOISE_TOMOGRAPHY/2nd/
+
 # visualization (refer to other examples, if you don't know the visualization process very well)
 # this program generates a file "$in_out_files/OUTPUT_FILES/$kernel.mesh"
 ./xcombine_vol_data 0 3 $kernel $in_out_files/DATABASES_MPI/  $in_out_files/OUTPUT_FILES/ 1



More information about the CIG-COMMITS mailing list
diff --git a/noise_tomography/NOISE_TOMOGRAPHY.m b/noise_tomography/NOISE_TOMOGRAPHY.m
index 0ea0290..863d054 100644
--- a/noise_tomography/NOISE_TOMOGRAPHY.m
+++ b/noise_tomography/NOISE_TOMOGRAPHY.m
@@ -42,7 +42,7 @@ function [] = NOISE_TOMOGRAPHY(NSTEP,dt,Tmin,Tmax,NOISE_MODEL)
 % the source time function has been saved in:
 % /data2/yangl/3D_NOISE/S_squared
 % S_squared should be put into directory:
 % ./NOISE_TOMOGRAPHY/ in the SPECFEM3D package
 
 
 clf;
@@ -162,5 +162,5 @@ fprintf('\n*************************************************************\n');
 fprintf('the source time function has been saved in:\n');
 fprintf([DIR '/S_squared\n']);
 fprintf('S_squared should be put into directory:\n');
-fprintf('./NOISE_TOMOGRAPHY/ in the SPECFEM3D package\n');
+fprintf('in_out_files/NOISE_TOMOGRAPHY/ in the SPECFEM3D package\n');
 fprintf('*************************************************************\n');
@@ -42,7 +42,7 @@ function [] = NOISE_TOMOGRAPHY(NSTEP,dt,Tmin,Tmax,NOISE_MODEL)
 % /data2/yangl/3D_NOISE/S_squared
 % S_squared should be put into directory:
-% ./NOISE_TOMOGRAPHY/ in the SPECFEM3D package
+% in_out_files/NOISE_TOMOGRAPHY/ in the SPECFEM3D package
 
 